==> kubernetes-model-networking-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/IngressRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class IngressRuleFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent<A> {

    private String host;
    private io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder http;

    public IngressRuleFluentImpl() {
    }

    public IngressRuleFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRule instance) {
        this.withHost(instance.getHost()); 
        this.withHttp(instance.getHttp()); 
    }

    public String getHost() {
        return this.host;
    }

    public A withHost(String host) {
        this.host=host; return (A) this;
    }

    public Boolean hasHost() {
        return this.host != null;
    }

    public A withNewHost(StringBuilder arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(int[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(char[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(StringBuffer arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(byte[] arg1,int arg2) {
        return (A)withHost(new String(arg1, arg2));
    }

    public A withNewHost(byte[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(char[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withHost(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewHost(String arg1) {
        return (A)withHost(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildHttp instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue getHttp() {
        return this.http!=null?this.http.build():null;
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue buildHttp() {
        return this.http!=null?this.http.build():null;
    }

    public A withHttp(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue http) {
        _visitables.get("http").remove(this.http);
        if (http!=null){ this.http= new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder(http); _visitables.get("http").add(this.http);} return (A) this;
    }

    public Boolean hasHttp() {
        return this.http != null;
    }

    public IngressRuleFluent.HttpNested<A> withNewHttp() {
        return new HttpNestedImpl();
    }

    public IngressRuleFluent.HttpNested<A> withNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue item) {
        return new HttpNestedImpl(item);
    }

    public IngressRuleFluent.HttpNested<A> editHttp() {
        return withNewHttpLike(getHttp());
    }

    public IngressRuleFluent.HttpNested<A> editOrNewHttp() {
        return withNewHttpLike(getHttp() != null ? getHttp(): new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder().build());
    }

    public IngressRuleFluent.HttpNested<A> editOrNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue item) {
        return withNewHttpLike(getHttp() != null ? getHttp(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IngressRuleFluentImpl that = (IngressRuleFluentImpl) o;
        if (host != null ? !host.equals(that.host) :that.host != null) return false;
        if (http != null ? !http.equals(that.http) :that.http != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(host,  http,  super.hashCode());
    }

    public class HttpNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluentImpl<IngressRuleFluent.HttpNested<N>> implements IngressRuleFluent.HttpNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder builder;

            HttpNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue item) {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder(this, item);
                        
            }

            HttpNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder(this);
                        
            }

            public N and() {
                return (N) IngressRuleFluentImpl.this.withHttp(builder.build());
            }

            public N endHttp() {
                return and();
            }
    }


}

==> kubernetes-model-networking-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/IngressRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class IngressRuleFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent<A> {

    private String host;
    private io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder http;

    public IngressRuleFluentImpl() {
    }

    public IngressRuleFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRule instance) {
        this.withHost(instance.getHost()); 
        this.withHttp(instance.getHttp()); 
    }

    public String getHost() {
        return this.host;
    }

    public A withHost(String host) {
        this.host=host; return (A) this;
    }

    public Boolean hasHost() {
        return this.host != null;
    }

    public A withNewHost(StringBuilder arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(int[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(char[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(StringBuffer arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(byte[] arg1,int arg2) {
        return (A)withHost(new String(arg1, arg2));
    }

    public A withNewHost(byte[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(char[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withHost(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewHost(String arg1) {
        return (A)withHost(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildHttp instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue getHttp() {
        return this.http!=null?this.http.build():null;
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue buildHttp() {
        return this.http!=null?this.http.build():null;
    }

    public A withHttp(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue http) {
        _visitables.get("http").remove(this.http);
        if (http!=null){ this.http= new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder(http); _visitables.get("http").add(this.http);} return (A) this;
    }

    public Boolean hasHttp() {
        return this.http != null;
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent.HttpNested<A> withNewHttp() {
        return new HttpNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent.HttpNested<A> withNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue item) {
        return new HttpNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent.HttpNested<A> editHttp() {
        return withNewHttpLike(getHttp());
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent.HttpNested<A> editOrNewHttp() {
        return withNewHttpLike(getHttp() != null ? getHttp(): new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent.HttpNested<A> editOrNewHttpLike(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue item) {
        return withNewHttpLike(getHttp() != null ? getHttp(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IngressRuleFluentImpl that = (IngressRuleFluentImpl) o;
        if (host != null ? !host.equals(that.host) :that.host != null) return false;
        if (http != null ? !http.equals(that.http) :that.http != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(host,  http,  super.hashCode());
    }

    public class HttpNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent.HttpNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressRuleFluent.HttpNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder builder;

            HttpNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValue item) {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder(this, item);
                        
            }

            HttpNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressRuleValueBuilder(this);
                        
            }

            public N and() {
                return (N) IngressRuleFluentImpl.this.withHttp(builder.build());
            }

            public N endHttp() {
                return and();
            }
    }


}
